@@ -7,7 +7,7 @@ use Log::Any '$log';
 use LWP::Simple;
 use Parse::Number::ID qw(parse_number_id);
 
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(get_currencies convert_currency);
@@ -162,7 +162,7 @@ Finance::Currency::Convert::KlikBCA - Convert currencies using data from KlikBCA
 
 =head1 VERSION
 
-This document describes version 0.06 of Finance::Currency::Convert::KlikBCA (from Perl distribution Finance-Currency-Convert-KlikBCA), released on 2014-08-16.
+This document describes version 0.07 of Finance::Currency::Convert::KlikBCA (from Perl distribution Finance-Currency-Convert-KlikBCA), released on 2014-09-05.
 
 =head1 SYNOPSIS
 
@@ -249,7 +249,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Finance-Cu
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Finance-Currency-Convert-KlikBCA>.
+Source repository is at L<https://github.com/perlancar/perl-Finance-Currency-Convert-KlikBCA>.
 
 =head1 BUGS
 
@@ -261,11 +261,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
